class Scene {
    constructor(canvas) {
        this.canvas = canvas;
        this.context = canvas.getContext('2d');
        this.objects = [];
    }

    width() {
        return this.canvas.width;
    }

    height() {
        return this.canvas.height;
    }

    resize(width, height) {
        this.canvas.width = width;
        this.canvas.height = height;
    }

    autoResize() {
        this.canvas.width = window.innerWidth;
        this.canvas.height = window.innerHeight;
    }

    clear() {
        this.context.clearRect(0, 0, this.width(), this.height());
    }

    drawBackground() {
        this.context.fillStyle = 'rgb(255, 0, 0)';
        this.context.beginPath();
        this.context.rect(0, 0, this.canvas.width, this.canvas.height);
        this.context.fill();
    }

    update(time = 0.002) {
        for (let object of this.objects) {
            object.update(time);
        }
    }

    add(object) {
        this.objects.push(object);
    }

    render() {
        this.clear();
        this.drawBackground();

        for (let object of this.objects) {
            this.draw(object);
            // object.drawOn(this.canvas);
        }
    }

    draw(object) {
        let size = object.size * this.width();

        this.context.fillStyle = 'rgb(0, 0, 0)';
        this.context.beginPath();

        this.context.rect(
            object.x * this.width(),
            (1 - object.y) * this.height() - size,
            size,
            size,
        );
        this.context.fill();
    }

}
